# 2022-03-25 - Single Recipient Gauge Factory

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This factory has been deprecated in favor of an [updated version](../../20230215-single-recipient-gauge-factory-v2/) with weight-capped gauges.

Deployment of the `SingleRecipientGaugeFactory`, for liquidity gauges which forward their entire BAL allowance onto a single address.


## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`SingleRecipientGaugeFactory` artifact](./artifact/SingleRecipientGaugeFactory.json)
